@@ -739,7 +739,7 @@ def runCommand():
   try:
     setMiniShellHistory(app.config, command)
     command = "timeout 600 " + command
-    return jsonify(path=cwd, data=subprocess.check_output(command, stderr=subprocess.STDOUT, shell=True, cwd=cwd))
+    return jsonify(path=cwd, data=subprocess.check_output(command, stderr=subprocess.STDOUT, shell=True, cwd=cwd, env={'PATH': app.config['path']}))
   except subprocess.CalledProcessError as e:
     error = "Error : process exited with exit code " + str(e.returncode) + \
             "\nProcess says :\n" + e.output
